@@ -2,7 +2,7 @@ from filecmp import cmp
 from hashlib import md5
 from json import load as jload, dumps as jdumps
 from os import listdir, makedirs, chdir, rename
-from os.path import isdir, islink, join, exists, abspath
+from os.path import isdir, islink, join, exists, abspath, dirname
 from pickle import load as pload, dump as pdump
 from typing import Optional
 from regex import compile
@@ -90,38 +90,40 @@ def save(path: str, content: object, format: str = 'auto', encoding: str = 'utf-
 		fp.close()
 
 _decompress_formats = 'tar', 'zip', 'gzip', 'bzip2', 'rar', '7zip', 'lzma'
-def decompress(path: str, output: str, format: str = 'auto') -> None:
+def decompress(input_file: str, output_dir: str = None, format: str = 'auto') -> None:
 	''' Decompress the given file to the output directory regardless of its format. '''
-	format = detect_format(path, format, accept=_decompress_formats)
-	makedirs(output, exist_ok=True)
+	output_dir = dirname(input_file) if output_dir is None else output_dir
+	format = detect_format(input_file, format, accept=_decompress_formats)
+	makedirs(output_dir, exist_ok=True)
 	if format == 'zip':
 		from zipfile import ZipFile
-		with ZipFile(path, 'r') as zipped:
-			zipped.extractall(output)
+		with ZipFile(input_file, 'r') as i:
+			i.extractall(output_dir)
 	elif format == 'gzip':
 		from gzip import GzipFile
-		with GzipFile(path, 'r') as zipped, open(output, 'wb') as file_dest:
-			copyfileobj(zipped, file_dest)
+		o_dir = join(output_dir, input_file.rsplit('.', 1)[0])
+		with GzipFile(input_file, 'r') as i, open(o_dir, 'wb') as o:
+			copyfileobj(i, o)
 	elif format == 'rar':
 		from rarfile import RarFile
-		with RarFile(path, 'r') as zipped:
-			zipped.extractall(output)
+		with RarFile(input_file, 'r') as i:
+			i.extractall(output_dir)
 	elif format == 'bzip2':
 		from bz2 import open as open_bz2
-		with open_bz2(path, 'r') as zipped, open(output, 'wb') as file_dest:
-			copyfileobj(zipped, file_dest)
+		with open_bz2(input_file, 'r') as i, open(output_dir, 'wb') as o:
+			copyfileobj(i, o)
 	elif format == 'tar':
 		from tarfile import open as open_tar
-		with open_tar(path) as zipped:
-			zipped.extractall(output)
+		with open_tar(input_file) as i:
+			i.extractall(output_dir)
 	elif format == '7zip':
 		from py7zr import SevenZipFile
-		with SevenZipFile(path, 'r') as zipped:
-			zipped.extractall(output)
+		with SevenZipFile(input_file, 'r') as i:
+			i.extractall(output_dir)
 	elif format == 'lzma':
 		from lzma import open as open_lzma, decompress as lzdecompress
-		with open_lzma(path, 'r') as zipped, open(output, 'wb') as file_dest:
-			copyfileobj(lzdecompress(zipped), file_dest)
+		with open_lzma(input_file, 'r') as i, open(output_dir, 'wb') as o:
+			copyfileobj(lzdecompress(i), o)
 
 _detect_format_exts = OrderedDict((
 	('bytes', ('bin', 'db', 'dat', 'blob', 'bytes')),
